==> zio-aws-rds_2.12-5.17.112.1-sources.jar: zio/aws/rds/model/DeleteDbProxyEndpointResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteDbProxyEndpointResponse(
    dbProxyEndpoint: scala.Option[zio.aws.rds.model.DBProxyEndpoint] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse = {
    import DeleteDbProxyEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse
      .builder()
      .optionallyWith(dbProxyEndpoint.map(value => value.buildAwsValue()))(
        _.dbProxyEndpoint
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DeleteDbProxyEndpointResponse.ReadOnly =
    zio.aws.rds.model.DeleteDbProxyEndpointResponse.wrap(buildAwsValue())
}
object DeleteDbProxyEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DeleteDbProxyEndpointResponse =
      zio.aws.rds.model.DeleteDbProxyEndpointResponse(
        dbProxyEndpoint.map(value => value.asEditable)
      )
    def dbProxyEndpoint
        : scala.Option[zio.aws.rds.model.DBProxyEndpoint.ReadOnly]
    def getDbProxyEndpoint
        : ZIO[Any, AwsError, zio.aws.rds.model.DBProxyEndpoint.ReadOnly] =
      AwsError.unwrapOptionField("dbProxyEndpoint", dbProxyEndpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse
  ) extends zio.aws.rds.model.DeleteDbProxyEndpointResponse.ReadOnly {
    override val dbProxyEndpoint
        : scala.Option[zio.aws.rds.model.DBProxyEndpoint.ReadOnly] = scala
      .Option(impl.dbProxyEndpoint())
      .map(value => zio.aws.rds.model.DBProxyEndpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse
  ): zio.aws.rds.model.DeleteDbProxyEndpointResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-rds_2.12-6.20.78.3-sources.jar: zio/aws/rds/model/DeleteDbProxyEndpointResponse.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteDbProxyEndpointResponse(
    dbProxyEndpoint: Optional[zio.aws.rds.model.DBProxyEndpoint] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse = {
    import DeleteDbProxyEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse
      .builder()
      .optionallyWith(dbProxyEndpoint.map(value => value.buildAwsValue()))(
        _.dbProxyEndpoint
      )
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DeleteDbProxyEndpointResponse.ReadOnly =
    zio.aws.rds.model.DeleteDbProxyEndpointResponse.wrap(buildAwsValue())
}
object DeleteDbProxyEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DeleteDbProxyEndpointResponse =
      zio.aws.rds.model.DeleteDbProxyEndpointResponse(
        dbProxyEndpoint.map(value => value.asEditable)
      )
    def dbProxyEndpoint: Optional[zio.aws.rds.model.DBProxyEndpoint.ReadOnly]
    def getDbProxyEndpoint
        : ZIO[Any, AwsError, zio.aws.rds.model.DBProxyEndpoint.ReadOnly] =
      AwsError.unwrapOptionField("dbProxyEndpoint", dbProxyEndpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse
  ) extends zio.aws.rds.model.DeleteDbProxyEndpointResponse.ReadOnly {
    override val dbProxyEndpoint
        : Optional[zio.aws.rds.model.DBProxyEndpoint.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbProxyEndpoint())
        .map(value => zio.aws.rds.model.DBProxyEndpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DeleteDbProxyEndpointResponse
  ): zio.aws.rds.model.DeleteDbProxyEndpointResponse.ReadOnly = new Wrapper(
    impl
  )
}
